@@ -96,7 +96,12 @@
 							      ;; cons-cells and other bytes,
 							      ;; also report gc-user time
 
-#-(or cmu scl sbcl clisp allegro)
+#+lispworks
+(defun used-area (&optional unused)
+  (declare (ignore unused))
+  (getf (system:room-values) :total-allocated))
+
+#-(or cmu scl sbcl clisp allegro openmcl lispworks)
 (defun used-area (&optional unused)
   (declare (ignore unused))
   0)
@@ -376,8 +381,8 @@
       (loop
 	 do
 	 (catch #+kcl si::*quit-tag*
-		#+(or cmu scl sbcl) 'continue
-		#-(or kcl cmu scl sbcl) nil
+		#+(or cmu scl sbcl openmcl lispworks) 'continue
+		#-(or kcl cmu scl sbcl openmcl lispworks) nil
 		(catch 'macsyma-quit
 		  (continue input-stream batch-flag)
 		  (format t *maxima-epilog*)
@@ -486,16 +491,18 @@
     ans))
 
 (defun $system (&rest args)
-  #+gcl   (lisp:system (apply '$sconcat args))
-  #+clisp (ext:run-shell-command (apply '$sconcat args))
-  #+(or cmu scl) (ext:run-program "/bin/sh"
-				  (list "-c" (apply '$sconcat args)) :output t)
-  #+allegro (excl:run-shell-command (apply '$sconcat args) :wait t)
-  #+sbcl  (sb-ext:run-program "/bin/sh"
-			      (list "-c" (apply '$sconcat args)) :output t)
-  #+openmcl (ccl::run-program "/bin/sh"
-			      (list "-c" (apply '$sconcat args)) :output t)
-  #+abcl (extensions::run-shell-command (apply '$sconcat args)))
+  ;; If XMaxima is running, direct output from command into *SOCKET-CONNECTION*.
+  ;; From what I can tell, GCL, ECL, and Clisp cannot redirect the output into an existing stream. Oh well.
+  (let ((s (and (boundp '*socket-connection*) *socket-connection*)))
+    #+gcl (lisp:system (apply '$sconcat args))
+    #+ecl (si:system (apply '$concat args))
+    #+clisp (ext:run-shell-command (apply '$sconcat args))
+    #+(or cmu scl) (ext:run-program "/bin/sh" (list "-c" (apply '$sconcat args)) :output (or s t))
+    #+allegro (excl:run-shell-command (apply '$sconcat args) :wait t :output (or s nil))
+    #+sbcl (sb-ext:run-program "/bin/sh" (list "-c" (apply '$sconcat args)) :output (or s t))
+    #+openmcl (ccl::run-program "/bin/sh" (list "-c" (apply '$sconcat args)) :output (or s t))
+    #+abcl (extensions::run-shell-command (apply '$sconcat args) :output (or s *standard-output*))
+    #+lispworks (system:run-shell-command (apply '$sconcat args) :wait t)))
 
 (defun $room (&optional (arg nil arg-p))
   (if arg-p
