@@ -969,17 +969,10 @@
 	(t (cons (subst2s (car ex) pat)
 		 (subst2s (cdr ex) pat)))))
 
-;; Helper for simple-trig-arg
-(defun simple-trig-arg->=1 (x)
-  (and ($numberp x)
-       (or (great x 1)
-	   (alike1 x 1))))
-
-;; Match (c*x+b), where c and b are free of x and c is a number
-;; greater than or equal to 1.
+;; Match (c*x+b), where c and b are free of x 
 (defun simple-trig-arg (exp)
   (m2 exp '((mplus) ((mtimes)
-		     ((coefftt) (c simple-trig-arg->=1))
+		     ((coefftt) (c freevar))
 		     ((coefftt) (v varp)))
 	    ((coeffpp) (b freevar)))
       nil))
@@ -995,16 +988,21 @@
 	     ;; takes longer and longer as n gets larger and larger.
 	     ;; This is caused by the Risch integrator.  This is a
 	     ;; work-around for this issue.
-	     (let ((c (cdras 'c arg))
-		   (b (cdras 'b arg))
-		   (new-var (gensym "NEW-VAR-")))
-	       (let ((new-int (div ($integrate (maxima-substitute (div (sub new-var b) c)
-								  var exp)
-					       new-var)
-				   c)))
-		 (return-from monstertrig (maxima-substitute *trigarg* new-var new-int)))))
+	     (let* ((c (cdras 'c arg))
+		    (b (cdras 'b arg))
+		    (new-var (gensym "NEW-VAR-"))
+		    (new-exp (maxima-substitute (div (sub new-var b) c)
+						var exp))
+		    (new-int
+		     (if (every-trigarg-alike exp *trigarg*)
+			 ;; avoid endless recursion when more than one
+			 ;; trigarg exists
+			 (div ($integrate new-exp new-var) c)
+		       (rischint exp var))))
+		 (return-from monstertrig (maxima-substitute *trigarg* new-var new-int))))
 	    (t
-	     (return-from monstertrig (rischint exp var))))))
+	     (return-from monstertrig (rischint exp var)))
+)))
   (prog (*notsame* w *a* *b* y *d*) 
      (declare (special *notsame*))
 	(cond
@@ -1502,10 +1500,14 @@
 			     (list '(mtimes) y *d*)
 			     (list '(mtimes) -1 z))))))
 
-(defun find1 (y a) 
-  (cond ((eq y a) t)
-	((atom y) nil)
-	(t (or (find1 (car y) a) (find1 (cdr y) a)))))
+;; returns t if argument of every trig operation in y matches arg
+(defun every-trigarg-alike (y arg)
+  (cond ((atom y) t)
+	((optrig (caar y)) (alike1 arg (cadr y)))
+	(t (every (lambda (exp)
+		    (every-trigarg-alike exp arg))
+		  (cdr y)))))
+
 
 (defun matchsum (alist blist) 
   (prog (r s *c* *d*) 
